@@ -69,7 +69,8 @@ def make_non_gatekeeping_check(condition, failmessage):
     """Creates a check decorator that doesn't stop the a user from seeing a command.
 
     It only shows a "You don't have permission to use this" string (specified by failmessage)
-    if an invalid user tries to use it."""
+    if an invalid user tries to use it.
+    """
 
     def non_gatekeep_check(**kwargs):
         def decorator(command):
